@@ -4,8 +4,10 @@ module Test.Hspec.Expectations (
 
 -- * Setting expectations
   Expectation
+, expectationFailure
 , shouldBe
 , shouldSatisfy
+, shouldContain
 , shouldReturn
 
 -- * Expecting exceptions
@@ -35,12 +37,17 @@ module Test.Hspec.Expectations (
 ) where
 
 import           Prelude
-import           Test.HUnit
+import           Test.HUnit (Assertion, (@?=), assertBool, assertFailure)
 import           Control.Exception
 import           Data.Typeable
+import           Data.List (isInfixOf)
 
 type Expectation = Assertion
 
+-- | This is just an alias for HUnit's `assertFailure`.
+expectationFailure :: String -> Expectation
+expectationFailure = assertFailure
+
 infix 1 `shouldBe`, `shouldSatisfy`, `shouldReturn`, `shouldThrow`
 
 -- |
@@ -52,7 +59,15 @@ actual `shouldBe` expected = actual @?= expected
 -- |
 -- @v \`shouldSatisfy\` p@ sets the expectation that @p v@ is @True@.
 shouldSatisfy :: (Show a) => a -> (a -> Bool) -> Expectation
-v `shouldSatisfy` p = assertBool (show v ++ " did not satisfy predicate!") (p v)
+v `shouldSatisfy` p = assertBool ("predicate failed on: " ++ show v) (p v)
+
+-- |
+-- @list \`shouldContain\` sublist@ sets the expectation that @sublist@ is contained,
+-- wholly and intact, anywhere in the second.
+shouldContain :: (Show a, Eq a) => [a] -> [a] -> Expectation
+list `shouldContain` sublist = assertBool errorMsg (sublist `isInfixOf` list)
+  where
+    errorMsg = show list ++ " doesn't contain " ++ show sublist
 
 -- |
 -- @action \`shouldReturn\` expected@ sets the expectation that @action@
@@ -74,7 +89,7 @@ action `shouldThrow` p = do
   r <- try action
   case r of
     Right _ ->
-      assertFailure $
+      expectationFailure $
         "did not get expected exception: " ++ exceptionType
     Left e ->
       (`assertBool` p e) $
@@ -84,7 +99,7 @@ action `shouldThrow` p = do
     exceptionType = (show . typeOf . instanceOf) p
       where
         instanceOf :: Selector a -> a
-        instanceOf _ = error "Test.Hspec.Expectations.shouldThrow: brocken Typeable instance"
+        instanceOf _ = error "Test.Hspec.Expectations.shouldThrow: broken Typeable instance"
 
 anyException :: Selector SomeException
 anyException = const True
